Module model
jot_
core
0.5.1
Module model
Module Items
Structs
In crate jot_
core
jot_core
Module
model
Structs

Project
A Jot project groups tasks by theme or dispatch source.
Task
A Jot task extends joy-core::Item with recurrence and task-specific fields. Uses serde flatten to inherit all base Item fields.